import {Component, OnDestroy, OnInit} from '@angular/core';
import {OmpClass} from 'src/app/dao/omp-class';
import {UserInfoService} from 'src/app/services/user-info.service';
import {switchMap, takeWhile} from 'rxjs/operators';
import {ActivatedRoute, ParamMap} from '@angular/router';
import {MinutePaper} from 'src/app/dao/minute-paper';

@Component({
  selector: 'app-student-dashboard',
  templateUrl: './student-dashboard.component.html',
  styleUrls: ['./student-dashboard.component.css']
})
export class StudentDashboardComponent implements OnInit, OnDestroy {

  private isAlive = true;
  public classList: OmpClass[];
  public openPaperList: MinutePaper[];

  constructor(private userInfoService: UserInfoService,
              private route: ActivatedRoute) {}

  ngOnInit(): void {
    this.classList = [];
    this.getClassList();
    this.getOpenPapers();
  }

  ngOnDestroy(): void {
    this.isAlive = false;
  }

  private getClassList() {
    this.route.paramMap.pipe(switchMap((params: ParamMap) => this.userInfoService.getUserClasses(params.get('id'))))
      .subscribe((data: OmpClass[]) => {data.forEach(c => this.classList.push(c)); })
      .add(takeWhile(() => this.isAlive));
  }

  private getOpenPapers() {
    this.route.paramMap.pipe(switchMap((params: ParamMap) => this.userInfoService.getOpenPapers(params.get('id'))))
      .subscribe((data: MinutePaper[]) => {data.forEach(c => this.openPaperList.push(c)); })
      .add(takeWhile(() => this.isAlive));
  }

}
